<?php
namespace Controller;

use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request;

class Extract extends \Zeedhi\Framework\Controller\Simple {

    protected $extractService;
    protected $snackMessage;
    protected $util;


    public function __construct(\Service\Extract $extractService, \Util\SnackMessage $snackMessage, \Util\Util $util){
        $this->extractService = $extractService;

        $this->snackMessage = $snackMessage;
        $this->util = $util;
    }

    public function getExtract(Request\Filter $request, Response $response){
        try {
            $params = $request->getFilterCriteria()->getConditions();

            $CDCLIENTE    = $params[0]['value'];
            $CDCONSUMIDOR = $params[1]['value'];
            $DTINI        = $this->util->formatDate($params[2]['value']);
            $DTFIM        = $this->util->formatDate($params[3]['value']);

            $consumerExtract = $this->extractService->getExtract($CDCLIENTE, $CDCONSUMIDOR, $DTINI, $DTFIM);


            $consumerExtract = $this->_processExtract($consumerExtract);

            if (!empty($averageConsumption[0]['MEDIACONSUMO'])){
                $averageConsumption = sprintf("%.2f", $averageConsumption[0]['MEDIACONSUMO']);
                $averageConsumption = str_replace(".", ",", $averageConsumption);
            }
            else $averageConsumption = '0,00';

            $extractPeriod = array(
                'DTINI' => $DTINI,
                'DTFIM' => $DTFIM
            );

            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('ExtractRepository', $consumerExtract));

        } catch (\Exception $e){
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    private function _processExtract($result){
        $families = array();
        foreach ($result as &$extractEntry){
            $family = $extractEntry['IDPAI'];
            if (!isset($families[$family])){
                $families[$family] = array(
                    'IDPAI'          => null,
                    'ID'             => $family,
                    'CDFAMILISALD'   => $extractEntry['CDFAMILISALD'],
                    'SALDODISP'      => $extractEntry['SALDANT'],
                    'DTMOVEXTCONS'   => null,
                    'MOVIMENTACAO'   => (double)$extractEntry['MOVIMENTACAO'],
                    'DSMOVIMENTACAO' => $family,
                    'SALDOTOTAL'      => $extractEntry['SALDANT']
                );
                $families[$family]['MOVIMENTACAO'] = 0;
            }

            if ($extractEntry['IDTPMOVEXT'] == 'V' || $extractEntry['IDTPMOVEXT'] == 'D'){
                $extractEntry['MOVIMENTACAO'] = (-1) * $extractEntry['MOVIMENTACAO'];
            }

            if($extractEntry['PARENT'] === 'S'){
                $extractEntry['SALDODISP'] = $families[$family]['SALDOTOTAL'] + $extractEntry['MOVIMENTACAO'];
                $families[$family]['SALDOTOTAL'] = $extractEntry['SALDODISP'];
            }

            $extractEntry['MOVIMENTACAO'] = sprintf("%.2f", $extractEntry['MOVIMENTACAO']);
            $extractEntry['MOVIMENTACAO'] = str_replace(".", ",", $extractEntry['MOVIMENTACAO']);

            if($extractEntry['PARENT'] === 'S'){
                $extractEntry['SALDODISP'] = sprintf("%.2f", $extractEntry['SALDODISP']);
                $extractEntry['SALDODISP'] = str_replace(".", ",", $extractEntry['SALDODISP']);
            } else{
                $extractEntry['SALDODISP'] = '';
            }
        }

        foreach ($families as &$family){
            $family['SALDODISP'] = sprintf("%.2f", $family['SALDODISP']);
            $family['SALDODISP'] = str_replace(".", ",", $family['SALDODISP']);

            $current = array(
                'IDPAI' => $family['ID'],
                'ID' => null,
                'CDFAMILISALD' => $family['CDFAMILISALD'],
                'SALDODISP' => $family['SALDODISP'],
                'DTMOVEXTCONS' => null,
                'MOVIMENTACAO' => null,
                'IDTPMOVEXT' => 'C',
                'DSMOVIMENTACAO' => 'SALDO ANTERIOR'
            );

            array_unshift($result, $current);
            $family['SALDODISP'] = null;

            $family['MOVIMENTACAO'] = $family['SALDODISP'];
            array_push($result, $family);

            $family['SALDOTOTAL'] = sprintf("%.2f", $family['SALDOTOTAL']);
            $family['SALDOTOTAL'] = str_replace(".", ",", $family['SALDOTOTAL']);

            $total = array(
                'IDPAI' => $family['ID'],
                'ID' => null,
                'CDFAMILISALD' => $family['CDFAMILISALD'],
                'SALDODISP' => $family['SALDOTOTAL'],
                'DTMOVEXTCONS' => null,
                'MOVIMENTACAO' => null,
                'IDTPMOVEXT' => 'C',
                'DSMOVIMENTACAO' => 'SALDO ATUAL'
            );
            array_push($result, $total);
        }

        return $result;
    }

}