<?php
namespace Service;

use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;

class AutomaticRecharge {

	protected $entityManager;
    private $messagesService;

	public function __construct(\Doctrine\ORM\EntityManager $entityManager, \Service\MessagesService $messagesService){
		$this->entityManager = $entityManager;
        $this->messagesService = $messagesService;
	}

	public function getConsumers() {
        try {
		  return $this->entityManager->getConnection()->fetchAll(\Util\Query::GET_CONSUMERS, array());
        } catch (\Exception $e){
            $this->messagesService->writeLog("Ocorreu um erro ao buscar os consumidores: ".$e->getMessage());
            throw new \Exception($e->getMessage());
        }
	}

	public function getConsumerDefaultCreditCart(array $consumer) {
		$params = array(
			':CDCONSUMIDOR' => $consumer["CDCONSUMIDOR"],
			':CDCLIENTE' => $consumer["CDCLIENTE"]
		);
		return $this->entityManager->getConnection()->fetchAssoc(\Util\Query::GET_CONSUMERS_DEFAULT_CREDIT_CART, $params);
	}

	public function getFilial($CDCLIENTE) {
		$params = array(
			':CDCLIENTE' => $CDCLIENTE
		);
		return $this->entityManager->getConnection()->fetchAssoc(\Util\Query::GET_FILIAL, $params);
	}

	public function insertTransacao($NRTRANSACAO, $CDCLIENTE, $CDCONSUMIDOR, $VRRECARGARAUT, $NRULTNUM) {
		$params = array(
            ':NRTRANSACAO'  => $NRTRANSACAO,
			':DSTRANSACAO'  => "Transacao de RA iniciada",
			':NRNIT' 	    => null,
            ':CDCLIENTE'    => $CDCLIENTE,
            ':CDCONSUMIDOR' => $CDCONSUMIDOR,
            ':VRMOVEXTCONS' => $VRRECARGARAUT,
            ':NRULTNUM' => $NRULTNUM
		);
		$this->entityManager->getConnection()->executeQuery(\Util\Query::INSERT_TRANSACAO, $params);
	}

	public function insertTransacaoCons($NRTRANSACAO, $CDCLIENTE, $CDCONSUMIDOR) {
        $params = array(
            ':NRTRANSACAO' => $NRTRANSACAO,
            ':CDCLIENTE' => $CDCLIENTE,
            ':CDCONSUMIDOR' => $CDCONSUMIDOR
        );
		$this->entityManager->getConnection()->executeQuery(\Util\Query::INSERT_TRANSACAOCONS, $params);
	}

	public function updateTransacao($NRTRANSACAO, $DSTRANSACAO, $TRANSACTIONID) {
		$params = array(
			':NRTRANSACAO' => $NRTRANSACAO,
			':DSTRANSACAO' => $DSTRANSACAO,
			':NRNIT' => $TRANSACTIONID
		);

        $this->entityManager->getConnection()->executeQuery(\Util\Query::UPDATE_TRANSACAO, $params);
	}

	public function isFirstInsertion($CDCLIENTE, $CDCONSUMIDOR, $CDFAMILISALD) {
		$params = array(
		   ':CDCLIENTE' => $CDCLIENTE,
		   ':CDCONSUMIDOR' => $CDCONSUMIDOR,
		   ':CDFAMILISALD' => $CDFAMILISALD
		);
		return $this->entityManager->getConnection()->fetchAll(\Util\Query::IS_FIRST_INSERTION, $params);
	}

	public function getCurrentBalance($CDCLIENTE, $CDCONSUMIDOR, $CDFAMILISALD) {
        $params = array(
            ':CDCLIENTE' => $CDCLIENTE,
            ':CDCONSUMIDOR' => $CDCONSUMIDOR,
            ':CDFAMILISALD' => $CDFAMILISALD
        );
        return $this->entityManager->getConnection()->fetchAll(\Util\Query::GET_EXTRATOCONS_VRSALDCONEXT, $params);
	}

	public function insertExtratoCons($CDCLIENTE, $CDCONSUMIDOR, $CDFAMILISALD, $DSOPEEXTCONS, $VRMOVEXTCONS, $IDTPMOVEXT, $VRSALDCONEXT, $CDTIPORECE, $CDFILIAL){
        $params = array(
            ':CDCLIENTE' => $CDCLIENTE,
            ':CDCONSUMIDOR' => $CDCONSUMIDOR
        );
        $NRSEQMOVEXT = $this->entityManager->getConnection()->fetchAll(\Util\Query::GET_NRSEQMOVEXT, $params);

        $params = array(
            ':CDCLIENTE'    => $CDCLIENTE,
            ':CDCONSUMIDOR' => $CDCONSUMIDOR,
            ':CDFAMILISALD' => $CDFAMILISALD,
            ':DSOPEEXTCONS' => $DSOPEEXTCONS,
            ':VRMOVEXTCONS' => $VRMOVEXTCONS,
            ':IDTPMOVEXT'   => $IDTPMOVEXT,
            ':NRSEQMOVEXT'  => $NRSEQMOVEXT[0]['NRSEQMOVEXT'],
            ':VRSALDCONEXT' => $VRSALDCONEXT,
            ':CDTIPORECE'   => $CDTIPORECE,
            ':CDFILIAL'     => $CDFILIAL
        );
        $this->entityManager->getConnection()->executeQuery(\Util\Query::INSERT_EXTRATOCONS, $params);
	}

	public function checkBalance($CDCLIENTE, $CDCONSUMIDOR, $CDFAMILISALD){
		$params = array(
			':CDCLIENTE' => $CDCLIENTE,
			':CDCONSUMIDOR' => $CDCONSUMIDOR,
			':CDFAMILISALD' => $CDFAMILISALD
		);
		return $this->entityManager->getConnection()->fetchAll(\Util\Query::CHECK_BALANCE, $params);
	}

	public function createBalance($CDCLIENTE, $CDCONSUMIDOR, $CDFAMILISALD, $VRSALDCONFAM){
		$params = array(
			':CDCLIENTE' => $CDCLIENTE,
			':CDCONSUMIDOR' => $CDCONSUMIDOR,
			':CDFAMILISALD' => $CDFAMILISALD,
			':VRSALDCONFAM' => $VRSALDCONFAM
		);
		$this->entityManager->getConnection()->executeQuery(\Util\Query::CREATE_BALANCE, $params);
	}

	public function updateBalance($CDCLIENTE, $CDCONSUMIDOR, $CDFAMILISALD, $VRSALDCONFAM){
        $params = array(
            ':CDCLIENTE' => $CDCLIENTE,
            ':CDCONSUMIDOR' => $CDCONSUMIDOR,
            ':CDFAMILISALD' => $CDFAMILISALD,
            ':VRSALDCONFAM' => $VRSALDCONFAM
        );
        $this->entityManager->getConnection()->executeQuery(\Util\Query::UPDATE_BALANCE, $params);
	}

	public function getConsumerDetails($CDCLIENTE, $CDCONSUMIDOR){
        $params = array(
            ':CDCLIENTE' => $CDCLIENTE,
            ':CDCONSUMIDOR' => $CDCONSUMIDOR
        );
        return $this->entityManager->getConnection()->fetchAssoc(\Util\Query::GET_CONSUMER_DETAILS, $params);
	}

	public function getConsumerCPF($CDCLIENTE, $CDCONSUMIDOR){
        $params = array(
            ':CDCLIENTE' => $CDCLIENTE,
            ':CDCONSUMIDOR' => $CDCONSUMIDOR
        );
        return $this->entityManager->getConnection()->fetchAssoc(\Util\Query::GET_CONSUMER_CPF, $params);
	}

	public function getCardInfo($NRCPFRESPCON){
        $params = array(
            ':NRCPFRESPCON' => $NRCPFRESPCON
        );
        return $this->entityManager->getConnection()->fetchAssoc(\Util\Query::GET_CARD_INFO, $params);
	}

    public function newCode($counterName, $size){
        $nrseq = null;
        $connection = $this->entityManager->getConnection();
        $storedProcedure = new StoredProcedure($connection, 'NOVO_CODIGO');
        $storedProcedure->addParam(new Param('P_CONTADOR', Param::PARAM_INPUT, $counterName, Param::PARAM_TYPE_STR, strlen($counterName)));
        $storedProcedure->addParam(new Param('P_SEQUENCIAL', Param::PARAM_OUTPUT, $nrseq, Param::PARAM_TYPE_INT, 20));
        $result = $storedProcedure->execute();
        return substr($result['P_SEQUENCIAL'], strlen($result['P_SEQUENCIAL'])-$size);
    }

}