<?php

namespace Odhen\API\Service;

class CapptaPinpad {

    const IS_HOMOLOGATION = true;
    const SALVA_LOGS = true;

    protected $entityManager;
    protected $util;

    public function __construct(\Doctrine\ORM\EntityManager $entityManager, \Odhen\API\Util\Util $util) {
        $this->entityManager = $entityManager;
        $this->util          = $util;
    }

    public function configuraCappta($NRINSJURFILI, $CDTERTEF, &$com = null) {
        try {
            if (is_null($com)) {
                $retornoCom = $this->util->getCOMTef();
            } else {
                $retornoCom = array(
                    'error' => false,
                    'com'   => $com
                );
            }

            if (!$retornoCom['error']) {
                $com = $retornoCom['com'];
                
                // $retornoConfigura = self::resetaTransacao($com);
                // if (!$retornoConfigura['error']) {
                if (self::IS_HOMOLOGATION) {
                    $NRINSJURFILI = '42724382000146';
                    $CDTERTEF = '73';
                }
                $retornoConfigura = $com->configuraCappta($NRINSJURFILI, $CDTERTEF);
                $retornoConfigura = self::trataRetornoConfigura($retornoConfigura);
                self::trataLog('configuraCappta', is_array($retornoConfigura) ? $retornoConfigura['message'] : $retornoConfigura);
                // }
            }

            return $retornoConfigura;
        } catch (\Exception $e) {
            self::trataLog('configuraCappta', 'Exception: ' . utf8_decode($e->getMessage()));
            return array(
                'error'               => true,
                'message'             => 'Mensagem: ' . utf8_decode($e->getMessage()) . '.',
                'finishedTransaction' => true
            );
        }
    }

    public function iniciaCappta($IDTIPORECE, $totalSale, &$com = null) {
        try {
            if (is_null($com)) {
                $retornoCom = $this->util->getCOMTef();
            } else {
                $retornoCom = array(
                    'error' => false,
                    'com'   => $com
                );
            }
            
            if (!$retornoCom['error']) {
                $com = $retornoCom['com'];
                $retornoInicia = $com->iniciaCappta($IDTIPORECE, $totalSale);
                $retornoCom = self::trataRetornoInicia($retornoInicia);
            }

            self::trataLog('iniciaCappta', $retornoInicia);

            return $retornoCom;
        } catch (\Exception $e) {
            self::trataLog('iniciaCappta', 'Exception: ' . utf8_decode($e->getMessage()));
            return array(
                'error'               => true,
                'message'             => 'Mensagem: ' . utf8_decode($e->getMessage()) . '.',
                'finishedTransaction' => true
            );
        }
    }

    public function continuaCappta(&$com = null) {
        try {
            if (is_null($com)) {
                $retornoCom = $this->util->getCOMTef();
            } else {
                $retornoCom = array(
                    'error' => false,
                    'com'   => $com
                );
            }
            
            if (!$retornoCom['error']) {
                $com = $retornoCom['com'];
                $retornoContinua = $com->continuaCappta();
                $retornoCom = self::trataRetornoContinua($retornoContinua, $com);
            }

            self::trataLog('continuaCappta', $retornoContinua);

            return $retornoCom;
        } catch (\Exception $e) {
            self::trataLog('continuaCappta', 'Exception: ' . utf8_decode($e->getMessage()));
            return array(
                'error'               => true,
                'message'             => 'Mensagem: ' . utf8_decode($e->getMessage()) . '.',
                'finishedTransaction' => true
            );
        }
    }

    public function finalizaTransacao(&$com = null) {
        try {
            if (is_null($com)) {
                $retornoCom = $this->util->getCOMTef();
            } else {
                $retornoCom = array(
                    'error' => false,
                    'com'   => $com
                );
            }
            
            /* 1 -> confirma, 0 -> desfaz a transação */
            $confirma = '1';

            if (!$retornoCom['error']) {
                $com = $retornoCom['com'];
                $com->finalizaCappta($confirma);
                $retornoCom = array(
                    'error' => false,
                    'message' => 'Transação realizada com sucesso.',
                    'finishedTransaction' => true
                );
            }

            self::trataLog('finalizaCappta', json_encode($retornoCom));

            return $retornoCom;
        } catch (\Exception $e) {
            self::trataLog('finalizaCappta', 'Exception: ' . utf8_decode($e->getMessage()));
            return array(
                'error'               => true,
                'message'             => 'Mensagem: ' . utf8_decode($e->getMessage()) . '.',
                'finishedTransaction' => true
            );
        }
    }

    public function enviaParamCappta($param, &$com = null) {
        try {
            if (is_null($com)) {
                $retornoCom = $this->util->getCOMTef();
            } else {
                $retornoCom = array(
                    'error' => false,
                    'com'   => $com
                );
            }
            
            if (!$retornoCom['error']) {
                $com = $retornoCom['com'];
                $com->enviaParamCappta($param);
                $retornoCom = array(
                    'error' => false,
                    'message' => 'Prosseguindo com a transação (enviando parametros para a Cappta).',
                );
            }

            self::trataLog('enviaParam', 'Prosseguindo com a transação (enviando parametros para a Cappta).');

            return $retornoCom;
        } catch (\Exception $e) {
            self::trataLog('enviaParam', 'Exception: ' . utf8_decode($e->getMessage()));
            return array(
                'error'               => true,
                'message'             => 'Mensagem: ' . utf8_decode($e->getMessage()) . '.',
                'finishedTransaction' => true
            );
        }
    }

    private function trataRetornoConfigura($retornoConfigura) {
        switch ($retornoConfigura) {
            case 0:
                $retorno = array(
                    'error' => false,
                    'message' => 'Não ocorreu erro'
                );
                break;
            case 1:
                $retorno = array(
                    'error' => true,
                    'message' => 'Não autorizado. Por favor, realize a autenticação para utilizar o CapptaGpPlus.'
                );
                break;
            case 2:
                sleep(3);
                $retorno = array(
                    'error' => true,
                    'message' => 'O CapptaGpPlus esta sendo inicializado, tente novamente em alguns instantes.',
                    'shouldRetry' => false
                );
                break;
            case 3:
                $retorno = array(
                    'error' => true,
                    'message' => 'O formato da requisição recebida pelo CapptaGpPlus é inválido.'
                );
                break;
            case 4:
                $retorno = array(
                    'error' => true,
                    'message' => 'Operação cancelada pelo operador.'
                );
                break;
            case 7:
                $retorno = array(
                    'error' => true,
                    'message' => 'Ocorreu um erro interno no CapptaGpPlus.'
                );
                break;
            case 8:
                $retorno = array(
                    'error' => true,
                    'message' => 'Ocorreu um erro na comunicação entre a CappAPI e o CapptaGpPlus.'
                );
                break;
            default:
                $retorno = array(
                    'error' => true,
                    'message' => 'Falha ao configurar o Cliente SiTef.'
                );
                break;
        }
        return $retorno;
    }

    private function trataRetornoInicia($retornoInicia) {
        switch ($retornoInicia) {
            case 0:
                $retorno = array(
                    'error' => false,
                    'message' => 'Não ocorreu erro'
                );
                break;
            default:
                $retorno = array(
                    'error' => true,
                    'message' => 'Erro ao inicar Cappta.'
                );
                break;
        }
        return $retorno;
    }

    private function trataRetornoContinua($retornoContinua, $com) {
        $retornoContinua = self::trataRetornoDelphi($retornoContinua);
        switch ($retornoContinua['Resposta']) {
            case 1:
                $retorno = array(
                    'error' => false,
                    'message' => 'Prosseguindo com a transacao.',
                    'finishedTransaction' => true
                );
                break;
            case 2:
                $retorno = array(
                    'error' => true,
                    'message' => utf8_decode($retornoContinua['Mensagem']),
                    'finishedTransaction' => true
                );
                break;
            case 3:
                $retorno = array(
                    'error' => true,
                    'message' => utf8_decode($retornoContinua['Mensagem']),
                    'finishedTransaction' => false
                );
                break;
            case 4:
                self::enviaParamCappta('0', $com);
                $retorno = array(
                    'error' => false,
                    'message' => utf8_decode($retornoContinua['Mensagem']),
                    'finishedTransaction' => false
                );
                break;
            default:
                $retorno = array(
                    'error' => true,
                    'message' => 'Erro ao continuar transação. (Retorno não documentado)',
                    'finishedTransaction' => true
                );
                break;
        }
        return $retorno;
    }

    private function trataRetornoDelphi($retornoDll) {
         /*
        * Estrutura de retorno da dll:
        * "Resposta=10000#Comando=1#TipoCampo=-1#tamMinimo=0#tamMaximo=0#Buffer=Conectando SiTef#TamBuffer=2001#Continua=0"
        */
        $retornoFormatado = array();
        $retornoDll = explode('#', $retornoDll);
        
        foreach ($retornoDll as $retornoDll) {
            $retornoDll = explode('=', $retornoDll);
            $retornoFormatado[$retornoDll[0]] = $retornoDll[1];
        }
        
        return $retornoFormatado;
    }

    private function trataLog($field, $value) {
        if (self::SALVA_LOGS) {
            self::salvaEtapaTransacao($field, $value);
        }
    }

    private function salvaEtapaTransacao($field, $value) {
        $this->util->createFolder('C:\TEKNISA\TEF\LOGS');
    	$fileName = 'capptaTransaction_' . date('d-m-Y_H') . '.txt';

        $impFile = fopen('C:\TEKNISA\TEF\LOGS\\' . $fileName, 'a');

        $currentDateTime = date('d-m-Y_H-i-s');
        $transactionData = $currentDateTime . ' - ' . $field . ': ' . $value . "\r\n";

        fwrite($impFile, $transactionData);

        fclose($impFile);
    }

    private function resetaTransacao(&$com) {
        $com = $this->util->getCOMTef()['com'];
        $retorno = $com->configuraCappta('42724382000146', '73');
        $retorno = self::trataRetornoConfigura($retorno);

        if ($retorno['error']) {
            self::trataLog('ResetaTransacao', 'ERRO: configuraCappta -> ' . $retorno['message']);
        } else {
            $retorno = self::enviaParamCappta('0', $com);
            if ($retorno['error']) {
                self::trataLog('ResetaTransacao', 'ERRO: enviaParam -> ' . $retorno['message']);
            } else {
                $retorno = self::finalizaTransacao();
                if ($retorno['error']) 
                    self::trataLog('ResetaTransacao', 'ERRO: finalizaTransacao -> ' . $retorno['message']);
            }
        }
        return $retorno;
    }

    private function trataConfiguraCappta(&$com, $NRINSJURFILI, $CDTERTEF) {
        if (self::IS_HOMOLOGATION) {
            $NRINSJURFILI = '42724382000146';
            $CDTERTEF = '73';
        }

        do {
            $retornoConfigura = $com->configuraCappta($NRINSJURFILI, $CDTERTEF);
            $retornoConfigura = self::trataRetornoConfigura($retornoConfigura);
            self::trataLog('configuraCappta', is_array($retornoConfigura) ? $retornoConfigura['message'] : $retornoConfigura);
        } while (!isset($retornoCom['shouldRetry']));

        return $retornoConfigura;
    }
}