## Odhen Rating Component
Radio button field for mobile and desktop web aplications. Built with AngularJS for Zeedhi Framework

## Installation
**1)** First of all, check if you have Private Bower's Registry registered in your **.bowerrc** file.
```js
{
    "registry": {
        "search": [
            "http://192.168.122.56:5678/"
        ]
    }
}
```
**2)** Then install via Bower:
```bash
$ bower install --save odh-radio
```
**3)** After installed, you need to link the main component's JavaScript and CSS files in your index.html:
```html
<script src="bower_components/odh-radio/dist/odh-radio.js"></script>
<link rel="stylesheet" href="bower_components/odh-radio/dist/odh-radio.css" />
```
**4)** Configure the package for usign the component inside your Zeedhi project:
```javascript
{
    package: "odh-radio",
    baseUrl: "bower_components/odh-radio/dist/template/"
},
```
### Using as a field on your Zeedhi Project
After you installed the component, you must create a parent widget (form for example) a put the odh-radio field on the widget fields, like below:
```javascript
"fields": [
    {
        "name": "radio",
        "label": "Escolha uma opção abaixo",
        "isVisible": true,
        "template": "odh-radio#radio.html",
        "class": "12",
        "events": [],
        "actions" : [],
        "dataSource": {
            "data": [
                {
                    "id": "potatoe",
                    "title": "Batãtaã",
                    "subtitle": "E essas coisas",
                    "image": "http://image.ibb.co/kVKPZv/daniel_horroroso.jpg"
                },
                {
                    "id": "calzone",
                    "title": "Cãaalzone"
                },
                {
                    "id": "danone",
                    "title": "Dãanoninho",
                    "subtitle": "E essas coisas",
                    "image": "https://image.ibb.co/ckq2Kv/if_payment_method_card_visa_206684.png"
                }
            ]
        }
    }
]
```

## DataSource properties
Since we're using a radio component, the dataSource should be an array of objects, just as I showed on the example below. The dataSource object properties are:

| Property name | Type | Default | Description |
|---------------|------|---------|-------------|
| id | string | n/a | Unique identifier for that object, can be anything but unique |
| title | string | n/a | Row title |
| subtitle | string | n/a | Row subtitle (optional) |
| image | string | n/a | Row image (optional) |

*Obs: The image will be set to a maximum height of 22px*

## Getting selected option
To get the selected option, just invoke the field ```field.value()``` function. Here's an example:

```javascript
this.showSelectedOption = (radioField) => {
    const selectedOption = radioField.value();

    let msg;
    if (selectedOption) {
        msg = `Opção selecionada: ${selectedOption.title}`;
    } else {
        msg = 'Nenhuma opção selecionada';
    }
    ScreenService.showMessage(msg);
};
```

## Initialize with an option

To initialize the component with a default value, the field datasource has to be an object with a property ```checked = true```.
In your javascript code, inject the ApplicationContext and then call ```ApplicationContext.RadioController.setOption(radioField, itemChecked)```.
Like this you can get the selected value calling ``` field.value() ```

Here's an example:


```javascript
"fields": [
    {
        "name": "radio",
        "label": "Escolha uma opção abaixo",
        "isVisible": true,
        "template": "odh-radio#radio.html",
        "class": "12",
        "events": [],
        "actions" : [],
        "dataSource": {
            "data": [
                {
                    "id": "potatoe",
                    "title": "Batãtaã",
                    "subtitle": "E essas coisas",
                    "image": "http://image.ibb.co/kVKPZv/daniel_horroroso.jpg"
                },
                {
                    "id": "calzone",
                    "title": "Cãaalzone", 
                    "checked": true 
                },
                {
                    "id": "danone",
                    "title": "Dãanoninho",
                    "subtitle": "E essas coisas",
                    "image": "https://image.ibb.co/ckq2Kv/if_payment_method_card_visa_206684.png"
                }
            ]
        }
    }
]
```

```javascript
ApplicationContext.RadioController.setOption(radioField, itemChecked);
```

## Contributors
Luiz Baldi