function ExtractController(ScreenService, templateManager, ExtractService, LoginRepository, ExtractRepository){

    /* Gets the extract within the parameterized dates. */
    this.getExtract = function(DTINI, DTFIM){
        LoginRepository.findOne().then(function (consumerData){
            ExtractService.getExtract(consumerData['CDCLIENTE'], consumerData['CDCONSUMIDOR'], DTINI, DTFIM).then(function (requestData){
                if(requestData.length == 0){
                    ExtractRepository.clearAll();
                }
                ScreenService.openWindow('extract');
            });
        });
    };

    /* Resets the grid to erase previous data that might be loaded onto it . */
    this.resetGrid = function(widget){
        // Clear extract widget
        widget.dataSource.data = [];
        widget.plainTreeData = [];
        templateManager.updateTemplate();
        widget.dataSource.reload();

        // Clear and open filter popup
        popupWidget = templateManager.container.getWidget('choosePeriod');
        popupWidget.currentRow = {};
        //ScreenService.openPopup(templateManager.container.getWidget('choosePeriod'));
    };

    /* Summons the extract from the last 30 days. */
    this.extractByLastThirstyDays = function(){
        var date = new Date();

        var day = date.getDate();
        var actualMonth = date.getMonth() + 1; /* Months here are zero-based, so we add 1 to them. */
        var year = date.getFullYear();

        var DTFIM = day + '/' + actualMonth + '/' + year; /* End date. */

        var startDate = new Date();
        startDate.setDate(d.getDate()-30);

        var DTINI = startDate.getDate() + '/' + (startDate.getMonth() + 1) + '/' + startDate.getFullYear(); /* Start date. */

        this.getExtract(DTINI, DTFIM);
    };

    /* Summons the extract from the last month. */
    this.extractByLastMonth = function(){
        var date = new Date();

        var year = date.getFullYear();
        var lastMonth = date.getMonth();

        /* In case the last month was December (months here are zero-based). */
        if (lastMonth === 0) {
            lastMonth = 12;
            year -= 1;
        }

        /* Gets the last day of the month. */
        var d = new Date(year, lastMonth, 0);
        var lastDay = d.getDate();

        var DTINI = '1' + '/' + lastMonth + '/' + year; /* Start date. */
        var DTFIM = lastDay + '/' + lastMonth + '/' + year; /* End date. */

        this.getExtract(DTINI, DTFIM);
    };

    /* Opens the popup to allow the selection of the start date. */
    this.chooseDay4Extract = function(selectDay){
        selectDay.newRow();
        var date = new Date();
        var month = date.getMonth() + 1;
        var day = date.getDate();
        var year = date.getFullYear();

        var data = {"DTINI": day+'/'+month+'/'+year};
        selectDay.setCurrentRow(data);
        ScreenService.openPopup(selectDay);
    };

    /* Summons the extract using the date chosen with the popup. */
    this.extractSince = function(selectedDay){
        var date = new Date();

        var day = date.getDate();
        var month = date.getMonth() + 1;
        var year = date.getFullYear();

        var DTFIM = day + '/' + month + '/' + year;

        this.getExtract(selectedDay, DTFIM);
    };

    /* Sets max date when the user chooses the extractSince option. */
    this.setMaxDate = function(datePicker){
        var currentDate = new Date();
        var maxDate = currentDate.getFullYear() + '-' + (currentDate.getMonth()+1) + '-' + currentDate.getDate();
        datePicker['datetime-maxDate'] = maxDate;
        datePicker['datetime-defaultDate'] = currentDate.getFullYear()-1 + '-01-01 23:59';
    };

    this.setPeriod = function(row, widget){
        var stripeWidget = templateManager.container.getWidget('stripe');

        var dataInicial = moment(row.DTINI, 'DD/MM/YYYY');
        var dataFinal = moment(row.DTFIM, 'DD/MM/YYYY');

        if (dataFinal.diff(dataInicial) >= 0) {
            LoginRepository.findOne().then(function (consumerData){
                ExtractService.getExtract(consumerData['CDCLIENTE'], consumerData['CDCONSUMIDOR'], row.DTINI, row.DTFIM).then(function (requestData){
                    widget.dataSource.data = requestData;
                    stripeWidget.getField('DTINI').label = row.DTINI;
                    stripeWidget.getField('DTFIM').label = row.DTFIM;
                    templateManager.updateTemplate();
                });
            });
            ScreenService.closePopup();
        } else {
            ScreenService.showMessage('A data inicial não pode ser superior à data final.');
        }
    };

    this.setDefaultPeriod = function(widget){
        var stripeWidget = templateManager.container.getWidget('stripe');
        const date = new Date();

        var dataInicial = moment(date).subtract(1,'month');
        var dataFinal = moment(date);

        dataInicial = dataInicial.format('DD/MM/YYYY');
        dataFinal = dataFinal.format('DD/MM/YYYY');

        LoginRepository.findOne().then(function (consumerData){
            ExtractService.getExtract(consumerData['CDCLIENTE'], consumerData['CDCONSUMIDOR'], dataInicial, dataFinal).then(function (requestData){
                widget.dataSource.data = requestData;
                stripeWidget.getField('DTINI').label = dataInicial;
                stripeWidget.getField('DTFIM').label = dataFinal;
                templateManager.updateTemplate();
            });
        });
        ScreenService.closePopup();
    };

};

Configuration(function(ContextRegister){
    ContextRegister.register('ExtractController', ExtractController);
});
