function RestrictValueController(ScreenService, templateManager, RestrictValueService, LoginRepository, ValueRestrictionsRepository){

    /* Gets the consumer's value restrictions, and updates the value restrictions grid. */
    this.getValueRestrictions = function(gridWidget){
        ValueRestrictionsRepository.clearAll().then(function (){
            LoginRepository.findOne().then(function (consumerData){
                RestrictValueService.getValueRestrictions(consumerData['CDFILIAL'], consumerData['CDCLIENTE'], consumerData['CDCONSUMIDOR']).then(function (valueRestrictions){
                    gridWidget.reload();
                    gridWidget.activate();
                    templateManager.updateTemplate();
                });
            });
        });
    };

    /* Shows a popup that let's the user modify the current value restriction on the grid. */
    this.showUpdateValueRestrictionPopup = function(row, widget){
        delete widget.dataSource.data;
        widget.setCurrentRow(row);
        widget.currentRow.dailyLimit = row.VRCONSDIARAL;
        widget.label = row.NMFAMILISALD;
        ScreenService.openPopup(widget);
    };

    /* Updates the value restriction. */
    this.updateValueRestriction = function(row, gridWidget){
        value = parseFloat(row.dailyLimit.replace(',','.')).toFixed(2);
        if (value > 0){
            ValueRestrictionsRepository.clearAll().then(function (){
                LoginRepository.findOne().then(function (consumerData){
                    RestrictValueService.updateValueRestriction(consumerData['CDFILIAL'], consumerData['CDCLIENTE'], consumerData['CDCONSUMIDOR'], row.CDFAMILISALD, value).then(function (valueRestrictions){
                        gridWidget.reload();
                        templateManager.updateTemplate();
                        ScreenService.closePopup();
                        gridWidget.activate();
                    });
                });
            });
        }
        else {
            ScreenService.showMessage('O limite diário tem que ser maior que R$ 0,00.');
        }
    };

    /* Shows the popup that allows the user to add a value restriction. */
    this.showAddValueRestrictionPopup = function(widget){
        widget.setCurrentRow({});

        LoginRepository.findOne().then(function (consumerData){
            RestrictValueService.getUnrestrictedFamilies(consumerData['CDFILIAL'], consumerData['CDCLIENTE'], consumerData['CDCONSUMIDOR']).then(function (families){
                if (families.length == 0){
                    ScreenService.showMessage('Não há lojas disponíveis para a restrição diária.');
                }
                else if (families.length == 1){
                    widget.fields[0].reload();
                    widget.currentRow.NMFAMILISALD = families[0].NMFAMILISALD;
                    widget.currentRow.CDFAMILISALD = families[0].CDFAMILISALD;
                    if (widget.getField('NMFAMILISALD').dataSource.data.length > 0){
                        widget.getField('NMFAMILISALD').setValue(widget.getField('NMFAMILISALD').dataSource.data[0].NMFAMILISALD);
                    }
                    ScreenService.openPopup(widget);
                }
                else {
                    widget.fields[0].reload();
                    ScreenService.openPopup(widget);
                }
            });
        });
    };

    /* Adds a value restriction. */
    this.addValueRestriction = function(value, cdFamiliSald, nmFamiliSald, gridWidget){
        if (cdFamiliSald != '') {
            if (value != null) value = parseFloat(value.replace(',','.')).toFixed(2);
            else (value == 0);
            if (value > 0){
                ValueRestrictionsRepository.clearAll().then(function (){
                    LoginRepository.findOne().then(function (consumerData){
                        RestrictValueService.addValueRestriction(consumerData['CDFILIAL'], consumerData['CDCLIENTE'], consumerData['CDCONSUMIDOR'], cdFamiliSald, value).then(function (valueRestrictions){
                            gridWidget.reload();
                            templateManager.updateTemplate();
                            ScreenService.closePopup();
                            gridWidget.activate();
                        });
                    });
                });
            } else {
                ScreenService.showMessage('O limite diário tem que ser maior que R$ 0,00.');
            }
        } else {
            ScreenService.showMessage('Selecione a loja.');
        }
    };

    /* Deletes the selected restriction. */
    this.deleteValueRestriction = function(row, gridWidget){
        ScreenService.confirmMessage(
            'Deseja remover esta restrição?',
            'question',
            function(){
                ValueRestrictionsRepository.clearAll().then(function (){
                    LoginRepository.findOne().then(function (consumerData){
                        RestrictValueService.deleteValueRestriction(consumerData['CDFILIAL'], consumerData['CDCLIENTE'], consumerData['CDCONSUMIDOR'], row.CDFAMILISALD).then(function (valueRestrictions){
                            gridWidget.reload();
                            templateManager.updateTemplate();
                            ScreenService.closePopup();
                            gridWidget.activate();
                        });
                    });
                });
            },
            function(){}
        );
    };

};

Configuration(function(ContextRegister){
    ContextRegister.register('RestrictValueController', RestrictValueController);
});